RealGas
=======
[![DOI](https://zenodo.org/badge/266229430.svg)](https://zenodo.org/badge/latestdoi/266229430)
[![Documentation Status](https://readthedocs.org/projects/realgas/badge/?version=latest)](https://realgas.readthedocs.io/en/latest/?badge=latest)
![Python application](https://github.com/dejac001/RealGas/workflows/Python%20application/badge.svg)
![Upload Python Package](https://github.com/dejac001/RealGas/workflows/Upload%20Python%20Package/badge.svg)

Simple integration of real-gas effects into open source Chemical Engineering modeling and simulation environments.

Chemical processes involving gas-phases, such as membrane separations,
adsorption separations, and heterogeneous catalysis, are ubiquitous.
These processes are typically modeled assuming that the gas-phase
is ideal and that component heat capacities can be approximated
by constant effective values.
The purpose of this software package is to allow these assumptions
to be relaxed by automating the tediousness of a real gas formulation.

Documentation
=============
The online documentation is hosted at [read the docs](https://realgas.readthedocs.io/en/latest/).

Contributing
============
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
